@@ -269,6 +269,7 @@ class TextAccessorBase:
         """Call the str accessor function with transforming the Arrow series to pandas series
          and back."""
         pd_series = self.data.to_pandas()
+        pd_series.index = self.obj.index
         pd_result = getattr(pd_series.str, func)(*args, **kwargs)
         if isinstance(pd_result, pd.DataFrame):
             for c in pd_result.columns:
@@ -402,7 +403,7 @@ class TextAccessor(TextAccessorBase):
 
             if case:
                 contains_exact = getattr(
-                    pc, "binary_contains_exact", _text_contains_case_sensitive
+                    pc, "match_substring", _text_contains_case_sensitive
                 )
                 # Can just check for a match on the byte-sequence
                 return self._series_like(contains_exact(self.data, pat))
@@ -412,10 +413,9 @@ class TextAccessor(TextAccessorBase):
                 pass
         return self._call_str_accessor("contains", pat=pat, case=case, regex=regex)
 
-    def count(self, pat: str, case: bool = True, regex: bool = True) -> pd.Series:
+    def count(self, pat: str, regex: bool = True) -> pd.Series:
         if not regex:
-            if case:
-                return self._series_like(_text_count_case_sensitive(self.data, pat))
+            return self._series_like(_text_count_case_sensitive(self.data, pat))
         return self._call_str_accessor("count", pat=pat)
 
     def replace(
